# MySQLのインストール


# mysqlのリポジトリ追加
execute 'repositry' do
  user "root"
  command <<-EOL
    yum -y install http://dev.mysql.com/get/mysql57-community-release-el7-11.noarch.rpm
  EOL
  not_if "ls -l /etc/yum.repos.d/ | grep mysql-community.repo"
end


# インストール
%w(mysql-community-server).each do |pkg|
  package pkg do
    action :install
    options "--enablerepo=mysql57-community"
  end
end


#my.cnf backup
execute 'my.cnf backup' do
  command 'cp /etc/my.cnf /etc/my.cnf.bu'
  not_if 'test -f /etc/my.cnf.bu'
end

#ファイルmy.cnfへ追加設定

mycnf_setting = <<"EOL"

#言語設定追加
[mysqld]
character-set-server=utf8mb4
collation_server=utf8mb4_bin

[client]
default-character-set=utf8mb4

[mysqldump]
default-character-set=utf8mb4

EOL


file '/etc/my.cnf' do
  action :edit
  block do |content|
    #設定が追加済みかのチェック
    if not content =~ /default-character-set/ then
      content << mycnf_setting
    end
  end
end


# 起動。自動起動は設定済みのため必要なし
service 'mysqld' do
  action :restart
end


# 初期パスワードの変更
execute 'change initial password' do
  user "root"
  command <<-EOL
    mysqladmin -u root -p`grep "temporary password" /var/log/mysqld.log | awk '{printf $NF}'` password 12345aA!
  EOL
  not_if "mysql -u root -p12345aA! -e 'show databases;'"
end

